@@ -1,5 +1,5 @@
 # ` @importFrom stats pnorm
-euclidean_join <- function(a, b, by_a, by_b, block_by_a = NULL, block_by_b = NULL, n_bands = 30, band_width = 10, threshold = 1.0, r = .5, progress = FALSE) {
+euclidean_join <- function(a, b, by_a, by_b, block_by_a = NULL, block_by_b = NULL, n_bands = 30, band_width = 10, threshold = 1.0, r = .5, progress = FALSE, nthread = NULL) {
   stopifnot("'radius' must be greater than 0" = threshold > 0)
   stopifnot("There should be no NA's in by_a[1]" = !anyNA(a[[by_a[1]]]))
   stopifnot("There should be no NA's in by_a[2]" = !anyNA(a[[by_a[2]]]))
@@ -25,7 +25,8 @@ euclidean_join <- function(a, b, by_a, by_b, block_by_a = NULL, block_by_b = NUL
     n_bands = n_bands,
     r = r,
     progress = progress,
-    seed = round(runif(1, 0, 2^32))
+    seed = round(runif(1, 0, 2^32)),
+    nthread = nthread
   )
 
   return(list(match_table = match_table))
