@@ -26,6 +26,10 @@
 #' @param similarity_column An optional character vector. If provided, the data
 #'   frame will contain a column with this name giving the Hamming distance
 #'   between the two fields. Extra column will not be present if anti-joining.
+#' 
+#' @param nthread Maximum number of threads to use. If `NULL` (default),
+#'   Rayon's global thread pool is used, which typically uses all logical
+#'   CPU cores available.
 #'
 #' @return A tibble fuzzily-joined on the basis of the variables in `by.` Tries
 #'   to adhere to the same standards as the dplyr-joins, and uses the same
@@ -35,36 +39,34 @@
 #' @rdname hamming-joins
 #' @export
 #' @examples
-#' # load baby names data
-#' # install.packages("babynames")
-#' library(babynames)
+#' if (requireNamespace("babynames", quietly = TRUE)) {
+#'   baby_names <- data.frame(
+#'     name = tolower(unique(babynames::babynames$name))[1:500]
+#'   )
 #'
-#' baby_names <- data.frame(name = tolower(unique(babynames$name))[1:500])
-#' baby_names_mispelled <- data.frame(
-#'   name_mispelled = gsub("[aeiouy]", "x", baby_names$name)
-#' )
+#'   baby_names_mispelled <- data.frame(
+#'     name_mispelled = gsub("[aeiouy]", "x", baby_names$name)
+#'   )
 #'
-#' # Run the join and only keep rows that have a match:
-#' hamming_inner_join(
-#'   baby_names,
-#'   baby_names_mispelled,
-#'   by = c("name" = "name_mispelled"),
-#'   threshold = 3,
-#'   n_bands = 150,
-#'   band_width = 10,
-#'   clean = FALSE # default
-#' )
+#'   hamming_inner_join(
+#'     baby_names,
+#'     baby_names_mispelled,
+#'     by = c("name" = "name_mispelled"),
+#'     threshold = 3,
+#'     n_bands = 150,
+#'     band_width = 10,
+#'     clean = FALSE
+#'   )
 #'
-#' # Run the join and keep all rows from the first dataset, regardless of whether
-#' # they have a match:
-#' hamming_left_join(
-#'   baby_names,
-#'   baby_names_mispelled,
-#'   by = c("name" = "name_mispelled"),
-#'   threshold = 3,
-#'   n_bands = 150,
-#'   band_width = 10,
-#' )
+#'   hamming_left_join(
+#'     baby_names,
+#'     baby_names_mispelled,
+#'     by = c("name" = "name_mispelled"),
+#'     threshold = 3,
+#'     n_bands = 150,
+#'     band_width = 10
+#'   )
+#' }
 hamming_inner_join <- function(a, b,
                                by = NULL,
                                n_bands = 100,
@@ -72,7 +74,8 @@ hamming_inner_join <- function(a, b,
                                threshold = 2,
                                progress = FALSE,
                                clean = FALSE,
-                               similarity_column = NULL) {
+                               similarity_column = NULL,
+                               nthread = NULL) {
 
   fuzzy_join_core(a = a, b = b, by = by,
             join_func = hamming_join,
@@ -82,7 +85,8 @@ hamming_inner_join <- function(a, b,
             threshold = threshold,
             progress = progress,
             similarity_column = similarity_column,
-            clean = clean
+            clean = clean,
+            nthread = nthread
   )
 
 }
@@ -96,7 +100,8 @@ hamming_anti_join <- function(a, b,
                               threshold = 2,
                               progress = FALSE,
                               clean = FALSE,
-                              similarity_column = NULL) {
+                              similarity_column = NULL,
+                              nthread = NULL) {
 
   fuzzy_join_core(a = a, b = b, by = by,
             join_func = hamming_join,
@@ -106,7 +111,8 @@ hamming_anti_join <- function(a, b,
             threshold = threshold,
             progress = progress,
             similarity_column = similarity_column,
-            clean = clean
+            clean = clean,
+            nthread = nthread
   )
 }
 
@@ -119,7 +125,8 @@ hamming_left_join <- function(a, b,
                               threshold = 2,
                               progress = FALSE,
                               clean = FALSE,
-                              similarity_column = NULL) {
+                              similarity_column = NULL,
+                              nthread = NULL) {
 
   fuzzy_join_core(a = a, b = b, by = by,
             join_func = hamming_join,
@@ -129,7 +136,8 @@ hamming_left_join <- function(a, b,
             threshold = threshold,
             progress = progress,
             similarity_column = similarity_column,
-            clean = clean
+            clean = clean,
+            nthread = nthread
   )
 }
 
@@ -142,7 +150,8 @@ hamming_right_join <- function(a, b,
                                threshold = 2,
                                progress = FALSE,
                                clean = FALSE,
-                               similarity_column = NULL) {
+                               similarity_column = NULL,
+                               nthread = NULL) {
 
   fuzzy_join_core(a = a, b = b, by = by,
             join_func = hamming_join,
@@ -152,7 +161,8 @@ hamming_right_join <- function(a, b,
             threshold = threshold,
             progress = progress,
             similarity_column = similarity_column,
-            clean = clean
+            clean = clean,
+            nthread = nthread
   )
 }
 
@@ -166,7 +176,8 @@ hamming_full_join <- function(a, b,
                               threshold = 2,
                               progress = FALSE,
                               clean = FALSE,
-                              similarity_column = NULL) {
+                              similarity_column = NULL,
+                              nthread = NULL) {
   fuzzy_join_core(a = a, b = b, by = by,
             join_func = hamming_join,
             mode = "full",
@@ -175,6 +186,7 @@ hamming_full_join <- function(a, b,
             threshold = threshold,
             progress = progress,
             similarity_column = similarity_column,
-            clean = clean
+            clean = clean,
+            nthread = nthread
   )
 }
