@@ -19,12 +19,21 @@ echo $(find . -name "ci" -type d) | xargs rm -rf
 
 rust_files=$(find . -type f -name "*.rs")
 
+# for file in $rust_files; do
+#     perl -i -0777 -pe 's{/\*.*?\*/}{}gs; s{//.*$}{}mg' "$file"
+# done
+#
+#
 for file in $rust_files; do
-    if [[ ! "$file" == *zerocopy* ]]; then
-        sed -i "s/^\s*\\/\{2,\}.*$//g" $file
+    # Skip vendor/target directories and files containing 'zerocopy'
+    if [[ "$file" != *"/vendor/"* && "$file" != *"/target/"* && "$file" != *zerocopy* && "$file" != *syn* ]]; then
+        perl -i -pe '
+            s{//.*$}{} unless /#/ || m{".*//.*"};
+        ' "$file"
     fi
 done
 
+
 cd ..
 
 python rehash.py
@@ -32,6 +41,5 @@ python rehash.py
 tar -cJ --no-xattrs -f vendor.tar.xz vendor
 
 sed -i "s/checksum.*//g" Cargo.lock
-# rm Cargo.lock
 
 ls -lhtr
