@@ -1,12 +1,10 @@
 use ndarray::prelude::*;
 use ndarray_rand::rand_distr::{Normal, Uniform};
 use ndarray_rand::RandomExt;
-
+use rand::Rng;
 use rustc_hash::FxHasher;
 use std::hash::{Hash, Hasher};
 
-use rand::Rng;
-
 #[derive(Debug)]
 pub struct EuclidianHasher {
     a_vectors: Array2<f64>,
@@ -20,9 +18,9 @@ impl EuclidianHasher {
             a_vectors: Array2::random_using(
                 (d, band_width),
                 Normal::new(0.0, 1.0).expect("could not intialize normal!"),
-                rng
+                rng,
             ),
-            b_vectors: Array1::random_using(band_width, Uniform::new(0.0, r),rng),
+            b_vectors: Array1::random_using(band_width, Uniform::new(0.0, r), rng),
             r,
         }
     }
@@ -30,8 +28,7 @@ impl EuclidianHasher {
     pub fn hash(&self, x: ArrayView1<f64>) -> u64 {
         let numerator = x.dot(&self.a_vectors) + &self.b_vectors;
 
-        let rounded = (numerator / self.r)
-            .map(|x| x.ceil() as u64);
+        let rounded = (numerator / self.r).map(|x| x.ceil() as u64);
 
         let mut hasher = FxHasher::default();
 
